@@ -2051,7 +2051,11 @@ where
             ..self.ctx
         };
 
-        s.visit_mut_children_with(&mut *self.with_ctx(ctx));
+        s.init.visit_mut_with(self);
+        s.test.visit_mut_with(self);
+        s.update.visit_mut_with(self);
+
+        s.body.visit_mut_with(&mut *self.with_ctx(ctx));
 
         self.with_ctx(ctx).optimize_init_of_for_stmt(s);
     }
