@@ -1,7 +1,8 @@
 use std::ops::{Deref, DerefMut};
 
+use rustc_hash::FxHashMap;
 use swc_atoms::JsWord;
-use swc_common::{collections::AHashMap, Span};
+use swc_common::Span;
 use swc_ecma_ast::*;
 use swc_ecma_utils::{ident::IdentLike, prop_name_eq, ExprExt, Id};
 use swc_ecma_visit::{noop_visit_mut_type, VisitMut, VisitMutWith};
@@ -168,7 +169,7 @@ pub(crate) fn is_valid_for_lhs(e: &Expr) -> bool {
 }
 
 pub(crate) struct MultiReplacer {
-    pub vars: AHashMap<Id, Box<Expr>>,
+    pub vars: FxHashMap<Id, Box<Expr>>,
     pub changed: bool,
 }
 
